# YAESU 古典的Split controller
# 2022/11/1

# programmed by Toshi JA0RUG

import socket
import tkinter as tk
import tkinter.messagebox as txtmsg
import time

root = tk.Tk()
root.title('YAESU Split Controller')
root.configure(bg = "gray40")
root.geometry("300x210")
#root.geometry("300x210+2250+5")

split_flag = False
var = tk.StringVar()
var.set('Simplex')

RIG_HOST = "192.168.0.5"
RIG_PORT = 5555

# CWメッセージ表示内容
msg = ['JA0RUG', '599TU', 'JA0RUG JA0RUG', 'TU 599 599 BK']

rig_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
while True:
    try:
        rig_socket.connect((RIG_HOST, RIG_PORT))
        break

    except ConnectionRefusedError as e:
        ret = txtmsg.askyesno('確認', '無線機に接続できません. 再接続しますか？')
        if ret == True:
            continue
        else:
            exit()

    except TimeoutError as e:
        txtmsg.showerror("エラー", "サーバーに接続できません.\nプログラムを停止します.")
        exit()

def kbd(event): #ファンクションキーなどによる送信
    global settings
    key  = event.keysym

    try:

        if key =='F1':
            rig_socket.send(b'KY11;')

        elif key =='F2':
            rig_socket.send(b'KY12;')

        elif key =='F3':
            rig_socket.send(b'KY13;')

        elif key =='F4':
            rig_socket.send(b'KY14;')

        elif key =='Escape': # ESCキーは送信停止キー
            rig_socket.send(b'KY10;')

    except Exception as e:
        txtmsg.showerror('エラー', 'サーバーが切断しました.')
        exit()

def mouse_button_press(event):

    global split_flag

    try:

        if event.num == 1: # TXW
            if split_flag == True:
                rig_socket.send(b"TS1;") # TXW設定
                label_1['bg'] = 'red'

                rig_socket.send(b"LK0;") 
                label_3['fg'] = 'blue'

        elif event.num == 3: # SPLIT設定

            if split_flag == False:

                rig_socket.send(b"QS;") # クイックスプリットに切り替える
                rig_socket.send(b"LK1;") 
                rig_socket.send(b"LK3;") 

                var.set('Split')

                label_2['bg'] = 'green'
                label_3['fg'] = 'white'

                split_flag = True

            # Split解除
            else:

                rig_socket.send(b"FT2;")  # SPLIT解除コマンド

                # VFO-A, VFO-Bのロックを解除
                rig_socket.send(b"LK0;") 
                rig_socket.send(b"LK2;") 

                var.set('Simplex')
                label_2['bg'] = 'blue'
                label_3['fg'] = 'blue'

                split_flag = False

        # 受信周波数が変更できるように, 一時的にLock解除

        elif event.num == 2:

            if split_flag == True:

                rig_socket.send(b"LK0;") 
                label_3['fg'] = 'blue'

    except Exception as e:
        txtmsg.showerror('エラー', 'サーバーが切断しました.')
        exit()

def mouse_button_release(event):

    try:

        if split_flag == True:

            if event.num== 1:
                rig_socket.send(b"TS0;") # TXWをOFF
                rig_socket.send(b"LK1;") 

                label_1['bg'] = 'blue'
                label_3['fg'] = 'white'
                print('TXW OFF') 
                print("VFO-A Lock")

            elif event.num == 2:
                print("VFO-A Lock(Temporary Unlock Release)")
                rig_socket.send(b"LK1;") 
                label_3['fg'] = 'white'

    except Exception as e:
        txtmsg.showerror('エラー', 'サーバーが切断しました.')
        exit()

def exit_proc():
    if txtmsg.askokcancel('','終了しますか?'):
        rig_socket.close()
        root.destroy()

root.protocol('WM_DELETE_WINDOW', exit_proc)

tk.Label(root, text = ' F1 ' + msg[0], font=('', 14, 'bold'), fg='white', bg='gray20', anchor="w").pack(side = 'top', padx=5, pady=2, fill = 'both') # message 1
tk.Label(root, text = ' F2 ' + msg[1], font=('', 14, 'bold'), fg='white', bg='gray20', anchor="w").pack(side = 'top', padx=5, pady=2, fill = 'both') # message 2
tk.Label(root, text = ' F3 ' + msg[2], font=('', 14, 'bold'), fg='white', bg='gray20', anchor="w").pack(side = 'top', padx=5, pady=2, fill = 'both') # message 3
tk.Label(root, text = ' F4 ' + msg[3], font=('', 14, 'bold'), fg='white', bg='gray20', anchor="w").pack(side = 'top', padx=5, pady=2, fill = 'both') # message 4
tk.Label(root, text = ' ESC-Key TX OFF ',  font=('', 14, 'bold'), fg='white', bg='gray20',  anchor="w").pack(side  = 'top', padx=5, pady=2, fill = 'both') # TX OFF

frame = tk.Frame(root, bg = "gray40", pady=10)
frame.pack()

# TXWボタン動作ラベル
label_1 = tk.Label(frame, text = '  TXW  ', font=('', 12, 'bold'), fg='white', bg='blue', width = 8)

# クイックスプリット動作ラベル
label_2 = tk.Label(frame, textvariable = var, font=('', 12, 'bold'), fg='white', bg='blue', width = 8)

# クイックスプリット動作ラベル
label_3 = tk.Label(frame, text = "Lock", font=('', 12, 'bold'), fg='white', bg='blue', width = 8)

label_1.pack(side=tk.LEFT, padx=10, pady=2)
label_2.pack(side=tk.LEFT, padx=10, pady=2)
label_3.pack(side=tk.LEFT, padx=10, pady=2)

label_3['fg'] = 'blue'

# キーボード操作(CW)ルーチンへ
root.bind('<Any-KeyPress>', kbd)

# マウス操作(スプリット操作)ルーチンへ
root.bind("<ButtonPress>", mouse_button_press)
root.bind("<ButtonRelease>", mouse_button_release)

root.mainloop()
